@@ -17,6 +17,6 @@
 # along with PyGL2D.  If not, see <http://www.gnu.org/licenses/>.
 #===============================================================================
 
-import window, image, draw, font, rect, geometry
+import window, image, draw, font, geometry
 
-__version__ = "0.3.1"
\ No newline at end of file
+__version__ = "0.3.2"
