@@ -17,7 +17,7 @@
 # along with PyGL2D.  If not, see <http://www.gnu.org/licenses/>.
 #===============================================================================
 
-import image, rect
+import image
 import pygame
 
 from OpenGL.GL import *
@@ -81,17 +81,17 @@ class RenderText(object):
         """Returns the width of the font rendered image. <- return int
         """
         
-        return self.ren.get_width()*self.ren.scalar
+        return self.ren.get_width() * self.ren.scalar
     
     def get_height(self):
         """Returns the height of the font rendered image. <- return int
         """
         
-        return self.ren.get_height()*self.ren.scalar
+        return self.ren.get_height() * self.ren.scalar
     
     def get_rect(self):
         """Get the rect of the font rendered image. <- return rect.Rect
         """
         
-        return rect.Rect(0, 0, self.get_width(), self.get_height())
+        return pygame.rect.Rect(0, 0, self.get_width(), self.get_height())
 
